# GPTK: the General Python Tool Kit
This is a collection of code that I have found useful in my 
tinkerings, perhaps you'll find it useful, too.




## Installation
```sh
pip install gptk
```

## Usage
Use pydoc to peruse the package.  Everything included should be well
documented.
